package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchDemocratic;

/**
 * 民主生活会Service接口
 * 
 * @author ruoyi
 * @date 2023-07-20
 */
public interface ITBranchDemocraticService 
{
    /**
     * 查询民主生活会
     * 
     * @param democraticId 民主生活会主键
     * @return 民主生活会
     */
    public TBranchDemocratic selectTBranchDemocraticByDemocraticId(Long democraticId);

    /**
     * 查询民主生活会列表
     * 
     * @param tBranchDemocratic 民主生活会
     * @return 民主生活会集合
     */
    public List<TBranchDemocratic> selectTBranchDemocraticList(TBranchDemocratic tBranchDemocratic);

    /**
     * 新增民主生活会
     * 
     * @param tBranchDemocratic 民主生活会
     * @return 结果
     */
    public int insertTBranchDemocratic(TBranchDemocratic tBranchDemocratic);

    /**
     * 修改民主生活会
     * 
     * @param tBranchDemocratic 民主生活会
     * @return 结果
     */
    public int updateTBranchDemocratic(TBranchDemocratic tBranchDemocratic);

    /**
     * 批量删除民主生活会
     * 
     * @param democraticIds 需要删除的民主生活会主键集合
     * @return 结果
     */
    public int deleteTBranchDemocraticByDemocraticIds(Long[] democraticIds);

    /**
     * 删除民主生活会信息
     * 
     * @param democraticId 民主生活会主键
     * @return 结果
     */
    public int deleteTBranchDemocraticByDemocraticId(Long democraticId);
}
